@@ -16,6 +16,7 @@
 #include <QStandardPaths>
 #include <QUndoGroup>
 
+#include <kwidgetsaddons_version.h>
 #include <KToolBar>
 #include <KActionCollection>
 #include <KStandardAction>
@@ -41,8 +42,8 @@ ResourceEditor::ResourceEditor(QWidget *parent) :
     m_dataIndex(Application::dataIndex()),
     m_resourceModel(new ResourceModel(this)),
     m_categorizedResourceModel(new CategorizedResourceSortFilterProxyModel(this)),
-    m_currentResource(0),
-    m_backupResource(0),
+    m_currentResource(nullptr),
+    m_backupResource(nullptr),
     m_undoGroup(new QUndoGroup(this)),
     m_actionCollection(new KActionCollection(this)),
     m_newResourceAction(KStandardAction::openNew(this, SLOT(newResource()), m_actionCollection)),
@@ -319,7 +320,7 @@ void ResourceEditor::onResourceSelected()
     }
     else
     {
-        m_currentResource = 0;
+        m_currentResource = nullptr;
         m_deleteResourceAction->setEnabled(false);
         m_exportResourceAction->setEnabled(false);
     }
@@ -344,7 +345,7 @@ void ResourceEditor::clearResourceBackup()
     Q_ASSERT(m_backupResource);
 
     delete m_backupResource;
-    m_backupResource = 0;
+    m_backupResource = nullptr;
 }
 
 void ResourceEditor::save()
@@ -397,7 +398,7 @@ Resource* ResourceEditor::storeResource(Resource* resource, Resource* dataIndexR
 
     if (Course* course = qobject_cast<Course*>(resource))
     {
-        DataIndexCourse* dataIndexCourse = dataIndexResource == 0?
+        DataIndexCourse* dataIndexCourse = dataIndexResource == nullptr?
             new DataIndexCourse():
             dynamic_cast<DataIndexCourse*>(dataIndexResource);
 
@@ -405,14 +406,14 @@ Resource* ResourceEditor::storeResource(Resource* resource, Resource* dataIndexR
         dir.mkpath(QStringLiteral("courses"));
         dir.cd(QStringLiteral("courses"));
 
-        QString path = dataIndexResource == 0?
+        QString path = dataIndexResource == nullptr?
             dir.filePath(QStringLiteral("%1.xml").arg(course->id())):
             dataIndexCourse->path();
 
         if (!userDataAccess.storeCourse(course))
         {
             KMessageBox::error(this, i18n("Error while saving course to disk."));
-            return 0;
+            return nullptr;
         }
 
         dataIndexCourse->setSource(DataIndex::UserResource);
@@ -422,7 +423,7 @@ Resource* ResourceEditor::storeResource(Resource* resource, Resource* dataIndexR
         dataIndexCourse->setId(course->id());
         dataIndexCourse->setPath(path);
 
-        if (dataIndexResource == 0)
+        if (dataIndexResource == nullptr)
         {
             m_dataIndex->addCourse(dataIndexCourse);
         }
@@ -431,7 +432,7 @@ Resource* ResourceEditor::storeResource(Resource* resource, Resource* dataIndexR
     }
     else if (KeyboardLayout* keyboardLayout = qobject_cast<KeyboardLayout*>(resource))
     {
-        DataIndexKeyboardLayout* dataIndexKeyboardLayout = dataIndexResource == 0?
+        DataIndexKeyboardLayout* dataIndexKeyboardLayout = dataIndexResource == nullptr?
             new DataIndexKeyboardLayout():
             qobject_cast<DataIndexKeyboardLayout*>(dataIndexResource);
 
@@ -439,14 +440,14 @@ Resource* ResourceEditor::storeResource(Resource* resource, Resource* dataIndexR
         dir.mkpath(QStringLiteral("keyboardlayouts"));
         dir.cd(QStringLiteral("keyboardlayouts"));
 
-        QString path = dataIndexResource == 0?
+        QString path = dataIndexResource == nullptr?
             dir.filePath(QStringLiteral("%1.xml").arg(keyboardLayout->id())):
             dataIndexKeyboardLayout->path();
 
         if (!userDataAccess.storeKeyboardLayout(keyboardLayout))
         {
             KMessageBox::error(this, i18n("Error while saving keyboard layout to disk."));
-            return 0;
+            return nullptr;
         }
 
         dataIndexKeyboardLayout->setSource(DataIndex::UserResource);
@@ -455,7 +456,7 @@ Resource* ResourceEditor::storeResource(Resource* resource, Resource* dataIndexR
         dataIndexKeyboardLayout->setId(keyboardLayout->id());
         dataIndexKeyboardLayout->setPath(path);
 
-        if (dataIndexResource == 0)
+        if (dataIndexResource == nullptr)
         {
             m_dataIndex->addKeyboardLayout(dataIndexKeyboardLayout);
         }
@@ -506,7 +507,7 @@ bool ResourceEditor::importCourse(const QString& path)
     if (!resourceDataAccess.loadCourse(path, &course))
         return false;
 
-    DataIndexCourse* overwriteDataIndexCourse(0);
+    DataIndexCourse* overwriteDataIndexCourse(nullptr);
 
     for (int i = 0; i < m_dataIndex->courseCount(); i++)
     {
@@ -514,12 +515,21 @@ bool ResourceEditor::importCourse(const QString& path)
 
         if (testCourse->source() == DataIndex::BuiltInResource &&  testCourse->id() == course.id())
         {
-            switch (KMessageBox::questionYesNo(this, i18n("The selected course is already present as a built-in course."), QString(),
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+            switch (KMessageBox::questionTwoActions(this,
+#else
+            switch (KMessageBox::questionYesNo(this,
+#endif
+                                               i18n("The selected course is already present as a built-in course."), QString(),
                                                KGuiItem(i18n("Import as new course"), QStringLiteral("dialog-ok")),
                                                KStandardGuiItem::cancel()
             ))
             {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+                case KMessageBox::PrimaryAction:
+#else
                 case KMessageBox::Yes:
+#endif
                     course.setId(QUuid::createUuid().toString());
                     for (int j = 0; j < course.lessonCount(); j++)
                     {
@@ -534,13 +544,22 @@ bool ResourceEditor::importCourse(const QString& path)
 
         if (testCourse->source() == DataIndex::UserResource &&  testCourse->id() == course.id())
         {
-            switch (KMessageBox::questionYesNoCancel(this, i18n("The selected course is already present as a user course."), QString(),
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+            switch (KMessageBox::questionTwoActionsCancel(this,
+#else
+            switch (KMessageBox::questionYesNoCancel(this,
+#endif
+                                               i18n("The selected course is already present as a user course."), QString(),
                                                KGuiItem(i18n("Import as new course"), QStringLiteral("dialog-ok")),
                                                KStandardGuiItem::overwrite(),
                                                KStandardGuiItem::cancel()
             ))
             {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+                case KMessageBox::PrimaryAction:
+#else
                 case KMessageBox::Yes:
+#endif
                     course.setId(QUuid::createUuid().toString());
                     for (int j = 0; j < course.lessonCount(); j++)
                     {
@@ -548,7 +567,11 @@ bool ResourceEditor::importCourse(const QString& path)
                         lesson->setId(QUuid::createUuid().toString());
                     }
                     break;
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+                case KMessageBox::SecondaryAction:
+#else
                 case KMessageBox::No:
+#endif
                     overwriteDataIndexCourse = testCourse;
                     break;
                 default:
@@ -574,7 +597,7 @@ bool ResourceEditor::importKeyboardLayout(const QString& path)
     if (!resourceDataAccess.loadKeyboardLayout(path, &keyboardLayout))
         return false;
 
-    DataIndexKeyboardLayout* overwriteDataIndexKeyboardLayout(0);
+    DataIndexKeyboardLayout* overwriteDataIndexKeyboardLayout(nullptr);
 
     for (int i = 0; i < m_dataIndex->keyboardLayoutCount(); i++)
     {
@@ -582,12 +605,21 @@ bool ResourceEditor::importKeyboardLayout(const QString& path)
 
         if (testKeyboardLayout->source() == DataIndex::BuiltInResource &&  testKeyboardLayout->id() == keyboardLayout.id())
         {
-            switch (KMessageBox::questionYesNo(this, i18n("The selected keyboard layout is already present as a built-in keyboard layout."), QString(),
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+            switch (KMessageBox::questionTwoActions(this,
+#else
+            switch (KMessageBox::questionYesNo(this,
+#endif
+                                               i18n("The selected keyboard layout is already present as a built-in keyboard layout."), QString(),
                                                KGuiItem(i18n("Import as new keyboard layout"), QStringLiteral("dialog-ok")),
                                                KStandardGuiItem::cancel()
             ))
             {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+                case KMessageBox::PrimaryAction:
+#else
                 case KMessageBox::Yes:
+#endif
                     keyboardLayout.setId(QUuid::createUuid().toString());
                     break;
                 default:
@@ -597,16 +629,29 @@ bool ResourceEditor::importKeyboardLayout(const QString& path)
 
         if (testKeyboardLayout->source() == DataIndex::UserResource &&  testKeyboardLayout->id() == keyboardLayout.id())
         {
-            switch (KMessageBox::questionYesNoCancel(this, i18n("The selected keyboard layout is already present as a user keyboard layout."), QString(),
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+            switch (KMessageBox::questionTwoActionsCancel(this,
+#else
+            switch (KMessageBox::questionYesNoCancel(this,
+#endif
+                                               i18n("The selected keyboard layout is already present as a user keyboard layout."), QString(),
                                                KGuiItem(i18n("Import as new keyboard layout"), QStringLiteral("dialog-ok")),
                                                KStandardGuiItem::overwrite(),
                                                KStandardGuiItem::cancel()
             ))
             {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+                case KMessageBox::PrimaryAction:
+#else
                 case KMessageBox::Yes:
+#endif
                     keyboardLayout.setId(QUuid::createUuid().toString());
                     break;
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+                case KMessageBox::SecondaryAction:
+#else
                 case KMessageBox::No:
+#endif
                     overwriteDataIndexKeyboardLayout = testKeyboardLayout;
                     break;
                 default:
